@@ -37,7 +37,7 @@ G_DEFINE_TYPE_WITH_CODE (GClueClientInfo,
 
 struct _GClueClientInfoPrivate
 {
-        char *bus_name;
+        const char *bus_name;
         GDBusConnection *connection;
         GDBusProxy *dbus_proxy;
         guint watch_id;
@@ -256,7 +256,7 @@ gclue_client_info_init_async (GAsyncInitable     *initable,
         task = g_task_new (initable, cancellable, callback, user_data);
 
         g_dbus_proxy_new_for_bus (G_BUS_TYPE_SYSTEM,
-                                  G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+                                  G_DBUS_PROXY_FLAGS_NONE,
                                   NULL,
                                   "org.freedesktop.DBus",
                                   "/org/freedesktop/DBus",
