@@ -35,14 +35,14 @@
 #define AGENT_WAIT_TIMEOUT_USEC 100000 /* microseconds */
 
 static void
-gclue_service_manager_manager_iface_init (GClueDBusManagerIface *iface);
+gclue_service_manager_manager_iface_init (GClueManagerIface *iface);
 static void
 gclue_service_manager_initable_iface_init (GInitableIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GClueServiceManager,
                          gclue_service_manager,
-                         GCLUE_DBUS_TYPE_MANAGER_SKELETON,
-                         G_IMPLEMENT_INTERFACE (GCLUE_DBUS_TYPE_MANAGER,
+                         GCLUE_TYPE_MANAGER_SKELETON,
+                         G_IMPLEMENT_INTERFACE (GCLUE_TYPE_MANAGER,
                                                 gclue_service_manager_manager_iface_init)
                          G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
                                                 gclue_service_manager_initable_iface_init))
@@ -57,15 +57,12 @@ struct _GClueServiceManagerPrivate
         gint64 init_time;
 
         GClueLocator *locator;
-
-        gboolean active;
 };
 
 enum
 {
         PROP_0,
         PROP_CONNECTION,
-        PROP_ACTIVE,
         LAST_PROP
 };
 
@@ -74,22 +71,14 @@ static GParamSpec *gParamSpecs[LAST_PROP];
 static void
 sync_in_use_property (GClueServiceManager *manager)
 {
-        gboolean in_use = FALSE, active = FALSE;
+        gboolean in_use = FALSE;
         GList *clients, *l;
-        GClueDBusManager *gdbus_manager;
 
         clients = g_hash_table_get_values (manager->priv->clients);
         for (l = clients; l != NULL; l = l->next) {
-                GClueDBusClient *client = GCLUE_DBUS_CLIENT (l->data);
-                GClueConfig *config;
-                const char *id;
+                GClueClient *client = GCLUE_CLIENT (l->data);
 
-                id = gclue_dbus_client_get_desktop_id (client);
-                config = gclue_config_get_singleton ();
-
-                active |= gclue_dbus_client_get_active (client);
-                if (gclue_dbus_client_get_active (client) &&
-                    !gclue_config_is_system_component (config, id)) {
+                if (gclue_client_get_active (client)) {
                         in_use = TRUE;
 
                         break;
@@ -97,13 +86,8 @@ sync_in_use_property (GClueServiceManager *manager)
         }
         g_list_free (clients);
 
-        if (manager->priv->active != active) {
-                manager->priv->active = active;
-                g_object_notify (G_OBJECT (manager), "active");
-        }
-        gdbus_manager = GCLUE_DBUS_MANAGER (manager);
-        if (in_use != gclue_dbus_manager_get_in_use (gdbus_manager))
-                gclue_dbus_manager_set_in_use (gdbus_manager, in_use);
+        if (in_use != gclue_manager_get_in_use (GCLUE_MANAGER (manager)))
+                gclue_manager_set_in_use (GCLUE_MANAGER (manager), in_use);
 }
 
 static void
@@ -121,7 +105,7 @@ on_peer_vanished (GClueClientInfo *info,
 
 typedef struct
 {
-        GClueDBusManager *manager;
+        GClueManager *manager;
         GDBusMethodInvocation *invocation;
         GClueClientInfo *client_info;
 } OnClientInfoNewReadyData;
@@ -167,16 +151,14 @@ complete_get_client (OnClientInfoNewReadyData *data)
                                   G_CALLBACK (sync_in_use_property),
                                   data->manager);
 
-        gclue_dbus_manager_complete_get_client (data->manager,
-                                                data->invocation,
-                                                path);
+        gclue_manager_complete_get_client (data->manager, data->invocation, path);
         goto out;
 
 error_out:
-        g_dbus_method_invocation_return_error_literal (data->invocation,
-                                                       G_DBUS_ERROR,
-                                                       G_DBUS_ERROR_FAILED,
-                                                       error->message);
+        g_dbus_method_invocation_return_error (data->invocation,
+                                               G_DBUS_ERROR,
+                                               G_DBUS_ERROR_FAILED,
+                                               "%s", error->message);
 out:
         g_clear_error (&error);
         g_clear_object (&info);
@@ -201,10 +183,10 @@ on_client_info_new_ready (GObject      *source_object,
 
         info = gclue_client_info_new_finish (res, &error);
         if (info == NULL) {
-                g_dbus_method_invocation_return_error_literal (data->invocation,
-                                                               G_DBUS_ERROR,
-                                                               G_DBUS_ERROR_FAILED,
-                                                               error->message);
+                g_dbus_method_invocation_return_error (data->invocation,
+                                                       G_DBUS_ERROR,
+                                                       G_DBUS_ERROR_FAILED,
+                                                       "%s", error->message);
                 g_error_free (error);
                 g_slice_free (OnClientInfoNewReadyData, data);
 
@@ -233,7 +215,7 @@ on_client_info_new_ready (GObject      *source_object,
 }
 
 static gboolean
-gclue_service_manager_handle_get_client (GClueDBusManager      *manager,
+gclue_service_manager_handle_get_client (GClueManager          *manager,
                                          GDBusMethodInvocation *invocation)
 {
         GClueServiceManager *self = GCLUE_SERVICE_MANAGER (manager);
@@ -248,9 +230,9 @@ gclue_service_manager_handle_get_client (GClueDBusManager      *manager,
                 const gchar *existing_path;
 
                 existing_path = gclue_service_client_get_path (client);
-                gclue_dbus_manager_complete_get_client (manager,
-                                                        invocation,
-                                                        existing_path);
+                gclue_manager_complete_get_client (manager,
+                                                   invocation,
+                                                   existing_path);
                 return TRUE;
         }
 
@@ -267,7 +249,7 @@ gclue_service_manager_handle_get_client (GClueDBusManager      *manager,
 
 typedef struct
 {
-        GClueDBusManager *manager;
+        GClueManager *manager;
         GDBusMethodInvocation *invocation;
         GClueClientInfo *info;
         char *desktop_id;
@@ -317,15 +299,15 @@ on_agent_proxy_ready (GObject      *source_object,
                           G_CALLBACK (on_agent_vanished),
                           data->manager);
 
-        gclue_dbus_manager_complete_add_agent (data->manager, data->invocation);
+        gclue_manager_complete_add_agent (data->manager, data->invocation);
 
         goto out;
 
 error_out:
-        g_dbus_method_invocation_return_error_literal (data->invocation,
-                                                       G_DBUS_ERROR,
-                                                       G_DBUS_ERROR_FAILED,
-                                                       error->message);
+        g_dbus_method_invocation_return_error (data->invocation,
+                                               G_DBUS_ERROR,
+                                               G_DBUS_ERROR_FAILED,
+                                               "%s", error->message);
 out:
         g_clear_error (&error);
         add_agent_data_free (data);
@@ -341,31 +323,27 @@ on_agent_info_new_ready (GObject      *source_object,
         AddAgentData *data = (AddAgentData *) user_data;
         GError *error = NULL;
         GClueConfig *config;
-        const char *xdg_id;
 
         data->info = gclue_client_info_new_finish (res, &error);
         if (data->info == NULL) {
-                g_dbus_method_invocation_return_error_literal (data->invocation,
-                                                               G_DBUS_ERROR,
-                                                               G_DBUS_ERROR_FAILED,
-                                                               error->message);
+                g_dbus_method_invocation_return_error (data->invocation,
+                                                       G_DBUS_ERROR,
+                                                       G_DBUS_ERROR_FAILED,
+                                                       "%s", error->message);
                 g_error_free (error);
                 add_agent_data_free (data);
 
                 return;
         }
 
-        xdg_id = gclue_client_info_get_xdg_id (data->info);
         config = gclue_config_get_singleton ();
-        if (xdg_id != NULL ||
-            !gclue_config_is_agent_allowed (config,
+        if (!gclue_config_is_agent_allowed (config,
                                             data->desktop_id,
                                             data->info)) {
                 g_dbus_method_invocation_return_error (data->invocation,
                                                        G_DBUS_ERROR,
                                                        G_DBUS_ERROR_ACCESS_DENIED,
-                                                       "%s not allowed to act as agent",
-                                                       data->desktop_id);
+                                                       "Not whitelisted");
                 add_agent_data_free (data);
 
                 return;
@@ -381,7 +359,7 @@ on_agent_info_new_ready (GObject      *source_object,
 }
 
 static gboolean
-gclue_service_manager_handle_add_agent (GClueDBusManager      *manager,
+gclue_service_manager_handle_add_agent (GClueManager          *manager,
                                         GDBusMethodInvocation *invocation,
                                         const char            *id)
 {
@@ -431,10 +409,6 @@ gclue_service_manager_get_property (GObject    *object,
                 g_value_set_object (value, manager->priv->connection);
                 break;
 
-        case PROP_ACTIVE:
-                g_value_set_boolean (value, manager->priv->active);
-                break;
-
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         }
@@ -468,8 +442,8 @@ on_avail_accuracy_level_changed (GObject    *object,
 
         level = gclue_location_source_get_available_accuracy_level
                         (GCLUE_LOCATION_SOURCE (priv->locator));
-        gclue_dbus_manager_set_available_accuracy_level
-                (GCLUE_DBUS_MANAGER (user_data), level);
+        gclue_manager_set_available_accuracy_level (GCLUE_MANAGER (user_data),
+                                                    level);
 }
 
 static void
@@ -511,21 +485,6 @@ gclue_service_manager_class_init (GClueServiceManagerClass *klass)
         g_object_class_install_property (object_class,
                                          PROP_CONNECTION,
                                          gParamSpecs[PROP_CONNECTION]);
-
-        /**
-         * GClueServiceManager:active:
-         *
-         * Unlike the D-Bus 'InUse' property, this doesn't differentiate
-         * between system components and apps.
-         */
-        gParamSpecs[PROP_ACTIVE] = g_param_spec_boolean ("active",
-                                                         "Active",
-                                                         "If manager is active",
-                                                         FALSE,
-                                                         G_PARAM_READABLE);
-        g_object_class_install_property (object_class,
-                                         PROP_ACTIVE,
-                                         gParamSpecs[PROP_ACTIVE]);
 }
 
 static void
@@ -559,7 +518,7 @@ gclue_service_manager_initable_init (GInitable    *initable,
 }
 
 static void
-gclue_service_manager_manager_iface_init (GClueDBusManagerIface *iface)
+gclue_service_manager_manager_iface_init (GClueManagerIface *iface)
 {
         iface->handle_get_client = gclue_service_manager_handle_get_client;
         iface->handle_add_agent = gclue_service_manager_handle_add_agent;
@@ -581,9 +540,3 @@ gclue_service_manager_new (GDBusConnection *connection,
                                "connection", connection,
                                NULL);
 }
-
-gboolean
-gclue_service_manager_get_active (GClueServiceManager *manager)
-{
-        return manager->priv->active;
-}
