@@ -26,7 +26,7 @@
 #include <string.h>
 #include "gclue-web-source.h"
 #include "gclue-error.h"
-#include "gclue-location.h"
+#include "geocode-glib/geocode-location.h"
 
 /**
  * SECTION:gclue-web-source
@@ -48,7 +48,7 @@ struct _GClueWebSourcePrivate {
 
         guint64 last_submitted;
 
-        gboolean internet_available;
+        gboolean network_available;
 };
 
 G_DEFINE_ABSTRACT_TYPE (GClueWebSource, gclue_web_source, GCLUE_TYPE_LOCATION_SOURCE)
@@ -62,7 +62,7 @@ query_callback (SoupSession *session,
         GError *error = NULL;
         char *contents;
         char *str;
-        GClueLocation *location;
+        GeocodeLocation *location;
         SoupURI *uri;
 
         if (query->status_code == SOUP_STATUS_CANCELLED)
@@ -88,9 +88,7 @@ query_callback (SoupSession *session,
                                                                      &error);
         g_free (contents);
         if (error != NULL) {
-                g_warning ("Failed to parse following response: %s\n%s",
-                           error->message,
-                           contents);
+                g_warning ("Failed to query location: %s", error->message);
                 return;
         }
 
@@ -99,37 +97,12 @@ query_callback (SoupSession *session,
         g_object_unref (location);
 }
 
-static gboolean
-get_internet_available (void)
-{
-        GNetworkMonitor *monitor = g_network_monitor_get_default ();
-        gboolean available;
-
-#if GLIB_CHECK_VERSION(2, 44, 0)
-        available = (g_network_monitor_get_connectivity (monitor) ==
-                     G_NETWORK_CONNECTIVITY_FULL);
-#else
-        GSocketConnectable *connectable;
-
-        connectable = g_network_address_new ("location.services.mozilla.com",
-                                             80);
-        available = g_network_monitor_can_reach (monitor,
-                                                 connectable,
-                                                 NULL,
-                                                 NULL);
-        g_object_unref (connectable);
-#endif
-
-        return available;
-}
-
 static void
-refresh_accuracy_level (GClueWebSource *web)
+refresh_accuracy_level (GClueWebSource *web,
+                        gboolean        available)
 {
         GClueAccuracyLevel new, existing;
-        gboolean available;
 
-        available = get_internet_available ();
         existing = gclue_location_source_get_available_accuracy_level
                         (GCLUE_LOCATION_SOURCE (web));
         new = GCLUE_WEB_SOURCE_GET_CLASS (web)->get_available_accuracy_level
@@ -144,23 +117,23 @@ refresh_accuracy_level (GClueWebSource *web)
 }
 
 static void
-on_network_changed (GNetworkMonitor *monitor G_GNUC_UNUSED,
-                    gboolean         available G_GNUC_UNUSED,
+on_network_changed (GNetworkMonitor *monitor,
+                    gboolean         available,
                     gpointer         user_data)
 {
         GClueWebSource *web = GCLUE_WEB_SOURCE (user_data);
         GError *error = NULL;
-        gboolean last_available = web->priv->internet_available;
+        gboolean last_available = web->priv->network_available;
 
-        refresh_accuracy_level (web);
+        refresh_accuracy_level (web, available);
 
         if (!gclue_location_source_get_active (GCLUE_LOCATION_SOURCE (user_data)))
                 return;
 
-        web->priv->internet_available = get_internet_available ();
-        if (last_available == web->priv->internet_available)
-                return; /* We already reacted to network change */
-        if (!web->priv->internet_available) {
+        web->priv->network_available = available;
+        if (last_available == available)
+                return; /* We already reacted to netork change */
+        if (!available) {
                 g_debug ("Network unavailable");
                 return;
         }
@@ -228,8 +201,8 @@ gclue_web_source_constructed (GObject *object)
                                   "network-changed",
                                   G_CALLBACK (on_network_changed),
                                   object);
-        on_network_changed (NULL,
-                            TRUE,
+        on_network_changed (monitor,
+                            g_network_monitor_get_network_available (monitor),
                             object);
 }
 
@@ -264,11 +237,14 @@ gclue_web_source_init (GClueWebSource *web)
 void
 gclue_web_source_refresh (GClueWebSource *source)
 {
+        GNetworkMonitor *monitor;
+
         g_return_if_fail (GCLUE_IS_WEB_SOURCE (source));
 
-        if (get_internet_available ()) {
-                source->priv->internet_available = FALSE;
-                on_network_changed (NULL, TRUE, source);
+        monitor = g_network_monitor_get_default ();
+        if (g_network_monitor_get_network_available (monitor)) {
+                source->priv->network_available = FALSE;
+                on_network_changed (monitor, TRUE, source);
         }
 }
 
@@ -281,6 +257,7 @@ gclue_web_source_start (GClueLocationSource *source)
         if (!base_class->start (source))
                 return FALSE;
 
+        gclue_web_source_refresh (GCLUE_WEB_SOURCE (source));
         return TRUE;
 }
 
@@ -314,22 +291,23 @@ on_submit_source_location_notify (GObject    *source_object,
 {
         GClueLocationSource *source = GCLUE_LOCATION_SOURCE (source_object);
         GClueWebSource *web = GCLUE_WEB_SOURCE (user_data);
-        GClueLocation *location;
+        GNetworkMonitor *monitor;
+        GeocodeLocation *location;
         SoupMessage *query;
         GError *error = NULL;
 
         location = gclue_location_source_get_location (source);
         if (location == NULL ||
-            geocode_location_get_accuracy (GEOCODE_LOCATION (location)) >
+            geocode_location_get_accuracy (location) >
             SUBMISSION_ACCURACY_THRESHOLD ||
-            geocode_location_get_timestamp (GEOCODE_LOCATION (location)) <
+            geocode_location_get_timestamp (location) <
             web->priv->last_submitted + SUBMISSION_TIME_THRESHOLD)
                 return;
 
-        web->priv->last_submitted = geocode_location_get_timestamp
-                (GEOCODE_LOCATION (location));
+        web->priv->last_submitted = geocode_location_get_timestamp (location);
 
-        if (!get_internet_available ())
+        monitor = g_network_monitor_get_default ();
+        if (!g_network_monitor_get_network_available (monitor))
                 return;
 
         query = GCLUE_WEB_SOURCE_GET_CLASS (web)->create_submit_query
@@ -369,11 +347,10 @@ gclue_web_source_set_submit_source (GClueWebSource      *web,
         if (GCLUE_WEB_SOURCE_GET_CLASS (web)->create_submit_query == NULL)
                 return;
 
-        g_signal_connect_object (G_OBJECT (submit_source),
-                                 "notify::location",
-                                 G_CALLBACK (on_submit_source_location_notify),
-                                 G_OBJECT (web),
-                                 0);
+        g_signal_connect (G_OBJECT (submit_source),
+                          "notify::location", 
+                          G_CALLBACK (on_submit_source_location_notify),
+                          web);
 
         on_submit_source_location_notify (G_OBJECT (submit_source), NULL, web);
 }
